<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    
    <xsl:template match="/authenticate">
        <html>
            <head>
                <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0 user-scalable=1" />
                <meta http-equiv="X-UA-Compatible" content="IE=Edge" />
                <title></title>
                <link rel="stylesheet" href="call_list.css" type="text/css"/>
                <script type="text/javascript" src="call_list.js"></script>
            </head>
            <body>
                <xsl:if test="@challenge">
                    <xsl:attribute name="onload">request_authentication(&quot;<xsl:value-of select="@challenge"/>&quot;);</xsl:attribute>
                </xsl:if>
                <xsl:if test="not(@challenge)">
                    <div>Error</div>
                    <xsl:if test="@error">
                        <div class="inactive">
                            <xsl:value-of select="@error"/>
                        </div>
                    </xsl:if>
                </xsl:if>
            </body>
        </html>
    </xsl:template>

    <xsl:template match="/clear">
        <html>
            <head>
                <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0 user-scalable=1" />
                <meta http-equiv="X-UA-Compatible" content="IE=Edge" />
                <title></title>
                <link rel="stylesheet" href="call_list.css" type="text/css"/>
                <script type="text/javascript" src="call_list.js"></script>
            </head>
            <body>
                <xsl:attribute name="onload">clear_complete();</xsl:attribute>
            </body>
        </html>
    </xsl:template>

    <xsl:template match="/report">
        <html>
            <head>
                <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0 user-scalable=1" />
                <meta http-equiv="X-UA-Compatible" content="IE=Edge" />
                <title></title>
                <link rel="stylesheet" href="call_list.css" type="text/css"/>
                <script type="text/javascript" src="call_list.js"></script>
            </head>
            <body>
                <div class="box-head">
                    <input type="image" class="image-button right" alt="Clear" src="call_list_clear.png" onclick="javascript:clear_report();"/>
                    <input type="image" class="image-button" alt="Close" src="call_list_close.png" onclick="javascript:abort();"/>
                </div>
                <div class="box-body">
                    <xsl:apply-templates select="record"/>
                </div>
            </body>
        </html>
    </xsl:template>

    <xsl:template match="record">
        <xsl:if test="not(further-registration)">
            <xsl:variable name="dial">
                <xsl:call-template name="dial">
                    <xsl:with-param name="name" select="remote/@name"/>
                    <xsl:with-param name="number" select="remote/@number"/>
                </xsl:call-template>
            </xsl:variable>

            <xsl:variable name="moreinfo">
                <xsl:value-of select="count(flow/ev)>1 or (type and type/text())"/>
            </xsl:variable>
            
            <xsl:variable name="callback-dial">
                <xsl:if test="callback">
                    <xsl:call-template name="dial">
                        <xsl:with-param name="name" select="callback/@name"/>
                        <xsl:with-param name="number" select="callback/@number"/>
                    </xsl:call-template>
                </xsl:if>
            </xsl:variable>

            <div class="item">
                <div class="item-line">
                    <span class="component right fixed relative">
                        <xsl:call-template name="state-image">
                            <xsl:with-param name="state" select="status"/>
                        </xsl:call-template>
                        <xsl:if test="callback">
                            <xsl:call-template name="callback-image">
                                <xsl:with-param name="id">callback-<xsl:value-of select="position()"/></xsl:with-param>
                            </xsl:call-template>
                        </xsl:if>
                    </span>
                    <span class="component right inactive">
                        <xsl:value-of select="conn-duration"/>
                    </span>
                    <span class="component left fixed">
                        <xsl:choose>
                            <xsl:when test="dir='i'">
                                <img src="call_direction_in.png"/>
                            </xsl:when>
                            <xsl:when test="dir='o'">
                                <img src="call_direction_out.png"/>
                            </xsl:when>
                        </xsl:choose>
                    </span>
                    <span class="component clickable" onclick="javascript:dial('{$dial}','{id}');">
                        <xsl:call-template name="display">
                            <xsl:with-param name="dn" select="remote/@dn"/>
                            <xsl:with-param name="name" select="remote/@name"/>
                        </xsl:call-template>
                    </span>
                </div>
                <xsl:if test="callback">
                    <div class="item-line-moreinfo">
                        <div class="item-overlay" id="overlay-callback-{position()}" onclick="javascript:toggle_overlay('callback-{position()}');">
                            <span class="component right fixed">
                                <img src="call_list_callback.png"/>
                            </span>
                            <span class="component right inactive">
                                <xsl:value-of select="callback"/>
                            </span>
                            <span class="component left clickable" onclick="javascript:dial('{$callback-dial}',null);">
                                <xsl:call-template name="display">
                                    <xsl:with-param name="dn" select="callback/@dn"/>
                                    <xsl:with-param name="name" select="callback/@name"/>
                                    <xsl:with-param name="number" select="callback/@number"/>
                                </xsl:call-template>
                            </span>
                        </div>
                    </div>
                </xsl:if>
                <div class="item-line">
                    <span class="component right fixed">
                        <xsl:if test="$moreinfo='true'">
                            <xsl:call-template name="type-info">
                                <xsl:with-param name="id" select="position()"/>
                                <xsl:with-param name="type" select="type"/>
                            </xsl:call-template>
                        </xsl:if>
                    </span>
                    <span class="component right inactive">
                        <xsl:choose>
                            <xsl:when test="/report/mypbx[@today and @yesterday]">
                                <xsl:choose>
                                    <xsl:when test="time/@time >= /report/mypbx/@today">
                                        <xsl:value-of select="/report/translation/today"/>
                                        <xsl:value-of select="' '"/>
                                        <xsl:value-of select="substring-after(time, ' ')"/>
                                    </xsl:when>
                                    <xsl:when test="time/@time >= /report/mypbx/@yesterday">
                                        <xsl:value-of select="/report/translation/yesterday"/>
                                        <xsl:value-of select="' '"/>
                                        <xsl:value-of select="substring-after(time, ' ')"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:value-of select="time"/>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="time"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </span>
                    <span class="component clickable inactive" onclick="javascript:dial('{$dial}','{id}');">
                        <xsl:value-of select="$dial"/>
                    </span>
                </div>
                <xsl:if test="$moreinfo='true'">
                    <div class="item-line-moreinfo">
                        <div class="item-overlay" id="overlay-{position()}" onclick="javascript:toggle_overlay('{position()}');">
                            <xsl:apply-templates select="flow/ev"></xsl:apply-templates>
                        </div>
                    </div>
                </xsl:if>
            </div>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="ev">
        <xsl:variable name="ep1">
            <xsl:call-template name="display">
                <xsl:with-param name="dn" select="@ep1_dn"/>
                <xsl:with-param name="name" select="@ep1_name"/>
                <xsl:with-param name="number" select="@ep1_number"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="ep1-dial">
            <xsl:call-template name="dial">
                <xsl:with-param name="name" select="@ep1_name"/>
                <xsl:with-param name="number" select="@ep1_number"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="ep2">
            <xsl:call-template name="display">
                <xsl:with-param name="dn" select="@ep2_dn"/>
                <xsl:with-param name="name" select="@ep2_name"/>
                <xsl:with-param name="number" select="@ep2_number"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="ep2-dial">
            <xsl:call-template name="dial">
                <xsl:with-param name="name" select="@ep2_name"/>
                <xsl:with-param name="number" select="@ep2_number"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="remote-dial">
            <xsl:call-template name="dial">
                <xsl:with-param name="name" select="../../remote/@name"/>
                <xsl:with-param name="number" select="../../remote/@number"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="ep2-conf">
            <xsl:if test="$ep2-dial=$remote-dial">
                <xsl:value-of select="../../id"/>
            </xsl:if>
        </xsl:variable>
        <xsl:variable name="side">
            <xsl:choose>
                <xsl:when test="@caller='ep1'">right</xsl:when>
                <xsl:when test="@caller='ep2'">left</xsl:when>
                <xsl:when test="not($ep1='')">left</xsl:when>
                <xsl:when test="not($ep2='')">right</xsl:when>
            </xsl:choose>
        </xsl:variable>
        <div class="item-line">
            <span class="component right fixed">
                <xsl:if test="$side='right'">
                    <xsl:call-template name="type-image">
                        <xsl:with-param name="type" select="@type"/>
                        <xsl:with-param name="side" select="$side"/>
                    </xsl:call-template>
                </xsl:if>
            </span>
            <xsl:if test="$ep2">
                <span class="component right clickable" onclick="javascript:dial('{$ep2-dial}','{$ep2-conf}');">
                    <xsl:value-of select="$ep2"/>
                </span>
            </xsl:if>
            <xsl:if test="$side='right'">
                <span class="component right">
                    <xsl:call-template name="state-image">
                        <xsl:with-param name="state" select="@status"/>
                    </xsl:call-template>
                </span>
            </xsl:if>
            <xsl:if test="@caller='ep2'">
                <span class="component right">
                    <img src="call_direction_in.png"/>    
                </span>    
            </xsl:if>
            <span class="component left fixed">
                <xsl:if test="$side='left'">
                    <xsl:call-template name="type-image">
                        <xsl:with-param name="type" select="@type"/>
                        <xsl:with-param name="side" select="$side"/>
                    </xsl:call-template>
                </xsl:if>
            </span>
            <xsl:choose>
                <xsl:when test="@entry='true'">
                    <span class="component left">
                        <img src="call_list_self.png"/>
                    </span>
                </xsl:when>
                <xsl:when test="$ep1">
                    <span class="component left clickable" onclick="javascript:dial('{$ep1-dial}',null);">
                        <xsl:value-of select="$ep1"/>
                    </span>
                </xsl:when>
            </xsl:choose>
            <xsl:if test="@caller='ep1'">
                <span class="component left">
                    <img src="call_direction_out.png"/>    
                </span>    
            </xsl:if>
            <xsl:if test="$side='left'">
                <span class="component left">
                    <xsl:call-template name="state-image">
                        <xsl:with-param name="state" select="@status"/>
                    </xsl:call-template>
                </span>
            </xsl:if>
        </div>
    </xsl:template>
    
    <xsl:template name="display">
        <xsl:param name="dn"/>
        <xsl:param name="name"/>
        <xsl:param name="number"/>
        <xsl:choose>
            <xsl:when test="$dn">
                <xsl:value-of select="$dn"/>
            </xsl:when>
            <xsl:when test="$name">
                <xsl:value-of select="$name"/>
            </xsl:when>
            <xsl:when test="$number">
                <xsl:value-of select="$number"/>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template name="dial">
        <xsl:param name="name"/>
        <xsl:param name="number"/>
        <xsl:choose>
            <xsl:when test="$number">
                <xsl:value-of select="$number"/>
            </xsl:when>
            <xsl:when test="$name">
                <xsl:value-of select="$name"/>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template name="type-image">
        <xsl:param name="type"/>
        <xsl:param name="side"/>
        <xsl:choose>
            <xsl:when test="$type='ct' and $side='left'">
                <img src="call_ct_left.png"/>    
            </xsl:when>
            <xsl:when test="$type='ct' and $side='right'">
                <img src="call_ct_right.png"/>    
            </xsl:when>
            <xsl:when test="$type='cct' and $side='left'">
                <img src="call_cct_left.png"/>    
            </xsl:when>
            <xsl:when test="$type='cct' and $side='right'">
                <img src="call_cct_right.png"/>    
            </xsl:when>
            <xsl:when test="$type='cf' and $side='left'">
                <img src="call_cf_left.png"/>    
            </xsl:when>
            <xsl:when test="$type='cf' and $side='right'">
                <img src="call_cf_right.png"/>    
            </xsl:when>
            <xsl:when test="$type='pu' and $side='left'">
                <img src="call_pickup_left.png"/>
            </xsl:when>
            <xsl:when test="$type='pu' and $side='right'">
                <img src="call_pickup_right.png"/>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template name="type-info">
        <xsl:param name="id"/>
        <xsl:param name="type"/>
        
            <xsl:choose>
                <xsl:when test="$type='ct'">
                    <img class="clickable" id="moreinfo-{$id}" src="call_ct_left.png" onclick="javascript:toggle_overlay('{$id}');"/>    
                    <img class="clickable hidden" id="lessinfo-{$id}" src="call_list_collapse.png" onclick="javascript:toggle_overlay('{$id}');"/>    
                </xsl:when>
                <xsl:when test="$type='cct'">
                    <img class="clickable" id="moreinfo-{$id}" src="call_cct_left.png" onclick="javascript:toggle_overlay('{$id}');"/>    
                    <img class="clickable hidden" id="lessinfo-{$id}" src="call_list_collapse.png" onclick="javascript:toggle_overlay('{$id}');"/>    
                </xsl:when>
                <xsl:when test="$type='cf'">
                    <img class="clickable" id="moreinfo-{$id}" src="call_cf_left.png" onclick="javascript:toggle_overlay('{$id}');"/>    
                    <img class="clickable hidden" id="lessinfo-{$id}" src="call_list_collapse.png" onclick="javascript:toggle_overlay('{$id}');"/>    
                </xsl:when>
                <xsl:otherwise>
                    <img class="clickable" id="moreinfo-{$id}" src="call_list_expand.png" onclick="javascript:toggle_overlay('{$id}');"/>    
                    <img class="clickable hidden" id="lessinfo-{$id}" src="call_list_collapse.png" onclick="javascript:toggle_overlay('{$id}');"/>    
                </xsl:otherwise>
            </xsl:choose>
    </xsl:template>

    <xsl:template name="state-image">
        <xsl:param name="state"/>
        <xsl:choose>
            <xsl:when test="$state='co'">
                <img src="call_type_connected.png"/>
            </xsl:when>
            <xsl:when test="$state='bu'">
                <img src="call_type_busy.png"/>
            </xsl:when>
            <xsl:when test="$state='al'">
                <img src="call_type_alerting.png"/>
            </xsl:when>
            <xsl:when test="$state='er'">
                <img src="call_type_error.png"/>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template name="callback-image">
        <xsl:param name="id"/>
        <img id="moreinfo-{$id}" class="callback clickable" src="call_list_callback.png" onclick="toggle_overlay('{$id}');"/>
        <img id="lessinfo-{$id}" class="callback clickable hidden" src="call_list_callback.png" onclick="toggle_overlay('{$id}');"/>
    </xsl:template>
</xsl:stylesheet>
